@@ -1,4 +1,5 @@
-﻿define(['apphost', 'connectionManager', 'events', 'globalize', 'browser', 'require', 'dom', 'emby-tabs'], function (appHost, connectionManager, events, globalize, browser, require, dom) {
+﻿define(['apphost', 'connectionManager', 'events', 'globalize', 'browser', 'require', 'dom', 'embyRouter', 'emby-tabs'], function (appHost, connectionManager, events, globalize, browser, require, dom, embyRouter) {
+    'use strict';
 
     // Make sure this is pulled in after button and tab css
     require(['css!./dockedtabs']);
@@ -13,7 +14,7 @@
         })[0];
 
         if (view) {
-            Emby.Page.showItem(view);
+            embyRouter.showItem(view);
         }
     }
 
@@ -22,13 +23,13 @@
         switch (id) {
 
             case 'settings':
-                Emby.Page.showSettings();
+                embyRouter.showSettings();
                 break;
             case 'signout':
                 Dashboard.logout();
                 break;
             case 'selectserver':
-                Emby.Page.showSelectServer();
+                embyRouter.showSelectServer();
                 break;
             case 'reports':
                 Dashboard.navigate('reports.html');
@@ -98,6 +99,11 @@
 
         var commands = [];
 
+        commands.push({
+            name: globalize.translate('ButtonRemoteControl'),
+            id: 'remotecontrol'
+        });
+
         // manage server, metadata manager, reports, sync to other devices
         if (currentUser.Policy.IsAdministrator) {
             commands.push({
@@ -105,7 +111,7 @@
                 id: 'manageserver'
             });
 
-            if (dom.getWindowSize().innerWidth >= 800) {
+            if (dom.getWindowSize().innerWidth >= 1000) {
                 commands.push({
                     name: globalize.translate('MetadataManager'),
                     id: 'metadatamanager'
@@ -118,12 +124,7 @@
             });
         }
 
-        commands.push({
-            name: globalize.translate('ButtonRemoteControl'),
-            id: 'remotecontrol'
-        });
-
-        if (Dashboard.isConnectMode()) {
+        if (appHost.supports('multiserver')) {
             commands.push({
                 name: globalize.translate('HeaderSelectServer'),
                 id: 'selectserver'
@@ -157,7 +158,7 @@
         switch (index) {
 
             case 0:
-                Emby.Page.goHome();
+                embyRouter.goHome();
                 break;
             case 1:
                 showLibrariesMenu(this);
@@ -165,10 +166,10 @@
                 e.stopPropagation();
                 break;
             case 2:
-                Emby.Page.showLiveTV();
+                embyRouter.showLiveTV();
                 break;
             case 3:
-                Emby.Page.showFavorites();
+                embyRouter.showFavorites();
                 break;
             case 4:
                 Dashboard.navigate('mysync.html?mode=offline');
@@ -217,7 +218,7 @@
         var html = '';
 
         var liveTVButtonClass = appHost.supports('sync') ? ' dockedtab-midsize' : '';
-        
+
         html += '    <div is="emby-tabs" class="dockedtabs-tabs" data-selectionbar="false">\
             <button is="emby-button" class="dockedtabs-tab-button emby-tab-button emby-tab-button-active" data-index="0">\
                 <div class="dockedtabs-tab-button-foreground emby-button-foreground"><i class="dockedtabs-tab-button-icon md-icon">home</i><div>' + globalize.translate('TabHome') + '</div></div>\
@@ -322,25 +323,41 @@
         });
     }
 
+    var instance;
+
+    function onViewShow(e) {
+        if (e.detail.properties.indexOf('fullscreen') !== -1 || !Dashboard.getCurrentUserId()) {
+            instance.hide();
+        } else {
+            instance.show();
+        }
+    }
+
     function dockedTabs(options) {
 
         var self = this;
+        instance = self;
 
         self.element = render(options);
 
         events.on(connectionManager, 'localusersignedin', function (e, user) {
-            self.element.classList.remove('hide');
+            self.show();
             showUserTabs(user, self.element);
         });
 
         events.on(connectionManager, 'localusersignedout', function () {
-            self.element.classList.add('hide');
+            self.hide();
         });
 
         showCurrentUserTabs(self.element);
+        document.addEventListener('viewshow', onViewShow);
     }
 
     dockedTabs.prototype.destroy = function () {
+
+        document.removeEventListener('viewshow', onViewShow);
+        instance = null;
+
         var self = this;
 
         var elem = self.element;
@@ -349,5 +366,13 @@
         self.element = null;
     };
 
+    dockedTabs.prototype.show = function () {
+        this.element.classList.remove('hide');
+    };
+
+    dockedTabs.prototype.hide = function () {
+        this.element.classList.add('hide');
+    };
+
     return dockedTabs;
 });
\ No newline at end of file
