@@ -1,4 +1,5 @@
 ﻿define(['jQuery'], function ($) {
+    'use strict';
 
     function reloadList(page) {
 
@@ -83,15 +84,15 @@
         var context = getParameterByName('context');
 
         if (context == 'sync') {
-            Dashboard.setPageTitle(Globalize.translate('TitleSync'));
+            LibraryMenu.setTitle(Globalize.translate('TitleSync'));
             page.setAttribute('data-helpurl', 'https://github.com/MediaBrowser/Wiki/wiki/Sync');
         }
         else if (context == 'livetv') {
-            Dashboard.setPageTitle(Globalize.translate('TitleLiveTV'));
+            LibraryMenu.setTitle(Globalize.translate('TitleLiveTV'));
             page.setAttribute('data-helpurl', 'https://github.com/MediaBrowser/Wiki/wiki/Live%20TV');
         }
         else if (context == 'notifications') {
-            Dashboard.setPageTitle(Globalize.translate('TitleNotifications'));
+            LibraryMenu.setTitle(Globalize.translate('TitleNotifications'));
             page.setAttribute('data-helpurl', 'https://github.com/MediaBrowser/Wiki/wiki/Notifications');
         }
 
