@@ -1,4 +1,5 @@
 ﻿define(['jQuery'], function ($) {
+    'use strict';
 
     function loadPage(page, config, systemInfo) {
 
@@ -187,7 +188,12 @@
 
             ApiClient.getSystemInfo().then(function (systemInfo) {
 
-                page.querySelector('.fldSelectEncoderPathType').classList.remove('hide');
+                if (systemInfo.EncoderLocationType == "External") {
+                    page.querySelector('.fldSelectEncoderPathType').classList.add('hide');
+                } else {
+                    page.querySelector('.fldSelectEncoderPathType').classList.remove('hide');
+                }
+
                 loadPage(page, config, systemInfo);
             });
         });
