@@ -1,4 +1,4 @@
-﻿define(['libraryBrowser', 'emby-tabs', 'emby-button'], function (libraryBrowser) {
+﻿define(['libraryBrowser', 'playbackManager', 'emby-tabs', 'emby-button'], function (libraryBrowser, playbackManager) {
     'use strict';
 
     var defaultFirstSection = 'smalllibrarytiles';
@@ -68,10 +68,7 @@
 
             elem.innerHTML = '';
 
-            return new Promise(function (resolve, reject) {
-
-                resolve();
-            });
+            return Promise.resolve();
         }
     }
 
@@ -82,7 +79,7 @@
 
         var elem = page.querySelector('.sections');
 
-        if (!elem.innerHTML.length) {
+        //if (!elem.innerHTML.length) {
             var html = '';
             for (i = 0, length = sectionCount; i < length; i++) {
 
@@ -90,7 +87,7 @@
             }
 
             elem.innerHTML = html;
-        }
+        //}
 
         var promises = [];
 
@@ -348,12 +345,12 @@
         }
 
         view.addEventListener('viewshow', function (e) {
-            Events.on(MediaController, 'playbackstop', onPlaybackStop);
+            Events.on(playbackManager, 'playbackstop', onPlaybackStop);
             Events.on(ApiClient, "websocketmessage", onWebSocketMessage);
         });
 
         view.addEventListener('viewbeforehide', function (e) {
-            Events.off(MediaController, 'playbackstop', onPlaybackStop);
+            Events.off(playbackManager, 'playbackstop', onPlaybackStop);
             Events.off(ApiClient, "websocketmessage", onWebSocketMessage);
         });
 
