@@ -1,9 +1,15 @@
-﻿define(['imageLoader', 'layoutManager', 'viewManager', 'navdrawer', 'libraryBrowser', 'apphost', 'paper-icon-button-light', 'material-icons'], function (imageLoader, layoutManager, viewManager, navdrawer, libraryBrowser, appHost) {
+﻿define(['layoutManager', 'viewManager', 'libraryBrowser', 'embyRouter', 'playbackManager', 'paper-icon-button-light', 'material-icons'], function (layoutManager, viewManager, libraryBrowser, embyRouter, playbackManager) {
+    'use strict';
 
-    var navDrawerElement = document.querySelector('.mainDrawer');
-    var navDrawerScrollContainer = navDrawerElement.querySelector('.scrollContainer');
+    var enableBottomTabs = AppInfo.isNativeApp;
+    var enableLibraryNavDrawer = !enableBottomTabs;
+
+    var navDrawerElement;
+    var navDrawerScrollContainer;
     var navDrawerInstance;
 
+    var mainDrawerButton;
+
     function renderHeader() {
 
         var html = '';
@@ -11,21 +17,19 @@
         html += '<div class="primaryIcons">';
         var backIcon = browserInfo.safari ? 'chevron_left' : '&#xE5C4;';
 
-        html += '<button type="button" is="paper-icon-button-light" class="headerButton headerButtonLeft headerBackButton hide autoSize"><i class="md-icon">' + backIcon + '</i></button>';
+        html += '<button type="button" is="paper-icon-button-light" class="headerButton headerButtonLeft headerBackButton hide"><i class="md-icon">' + backIcon + '</i></button>';
 
-        html += '<button type="button" is="paper-icon-button-light" class="headerButton mainDrawerButton barsMenuButton headerButtonLeft autoSize"><i class="md-icon">menu</i></button>';
-        html += '<button type="button" is="paper-icon-button-light" class="headerButton headerAppsButton barsMenuButton headerButtonLeft autoSize"><i class="md-icon">home</i></button>';
+        html += '<button type="button" is="paper-icon-button-light" class="headerButton mainDrawerButton barsMenuButton headerButtonLeft hide"><i class="md-icon">menu</i></button>';
+        html += '<button type="button" is="paper-icon-button-light" class="headerButton headerAppsButton barsMenuButton headerButtonLeft"><i class="md-icon">home</i></button>';
 
-        html += '<div class="libraryMenuButtonText headerButton">' + Globalize.translate('ButtonHome') + '</div>';
+        html += '<h3 class="libraryMenuButtonText headerButton">' + Globalize.translate('ButtonHome') + '</h3>';
 
         html += '<div class="viewMenuSecondary">';
 
         html += '<span class="headerSelectedPlayer"></span>';
-        html += '<button is="paper-icon-button-light" class="btnCast headerButton headerButtonRight hide autoSize"><i class="md-icon">cast</i></button>';
+        html += '<button is="paper-icon-button-light" class="btnCast headerButton-btnCast headerButton headerButtonRight hide autoSize"><i class="md-icon">cast</i></button>';
 
-        if (AppInfo.enableSearchInTopMenu) {
-            html += '<button type="button" is="paper-icon-button-light" class="headerButton headerButtonRight headerSearchButton hide autoSize"><i class="md-icon">search</i></button>';
-        }
+        html += '<button type="button" is="paper-icon-button-light" class="headerButton headerButtonRight headerSearchButton hide autoSize"><i class="md-icon">search</i></button>';
 
         html += '<button is="paper-icon-button-light" class="headerButton headerButtonRight headerVoiceButton hide autoSize"><i class="md-icon">mic</i></button>';
 
@@ -33,7 +37,7 @@
 
         html += '<button is="paper-icon-button-light" class="headerButton headerButtonRight headerUserButton autoSize"><i class="md-icon">person</i></button>';
 
-        if (!browserInfo.mobile && !Dashboard.isConnectMode()) {
+        if (!browserInfo.mobile) {
             html += '<button is="paper-icon-button-light" class="headerButton headerButtonRight dashboardEntryHeaderButton autoSize" onclick="return LibraryMenu.onSettingsClicked(event);"><i class="md-icon">settings</i></button>';
         }
 
@@ -49,15 +53,20 @@
 
         document.querySelector('.skinHeader').appendChild(viewMenuBar);
 
-        imageLoader.lazyChildren(document.querySelector('.viewMenuBar'));
+        lazyLoadViewMenuBarImages();
 
-        document.dispatchEvent(new CustomEvent("headercreated", {}));
         bindMenuEvents();
     }
 
+    function lazyLoadViewMenuBarImages() {
+        require(['imageLoader'], function (imageLoader) {
+            imageLoader.lazyChildren(document.querySelector('.viewMenuBar'));
+        });
+    }
+
     function onBackClick() {
 
-        Emby.Page.back();
+        embyRouter.back();
     }
 
     function updateUserInHeader(user) {
@@ -136,13 +145,11 @@
             }
 
             require(['apphost'], function (apphost) {
-
                 if (apphost.supports('voiceinput')) {
-                    header.querySelector('.headerVoiceButton').classList.remove('hide');
+                    header.querySelector('.headerVoiceButton').classList.add('hide');
                 } else {
                     header.querySelector('.headerVoiceButton').classList.add('hide');
                 }
-
             });
 
         } else {
@@ -179,7 +186,7 @@
 
     function bindMenuEvents() {
 
-        var mainDrawerButton = document.querySelector('.mainDrawerButton');
+        mainDrawerButton = document.querySelector('.mainDrawerButton');
 
         if (mainDrawerButton) {
             mainDrawerButton.addEventListener('click', toggleMainDrawer);
@@ -216,6 +223,21 @@
         viewMenuBar.querySelector('.btnNotifications').addEventListener('click', function () {
             Dashboard.navigate('notificationlist.html');
         });
+
+        var btnCast = document.querySelector('.headerButton-btnCast');
+
+        if (btnCast) {
+            btnCast.addEventListener('click', onCastButtonClicked);
+        }
+    }
+
+    function onCastButtonClicked() {
+
+        var btn = this;
+
+        require(['playerSelectionMenu'], function (playerSelectionMenu) {
+            playerSelectionMenu.show(btn);
+        });
     }
 
     function getItemHref(item, context) {
@@ -304,7 +326,7 @@
         html += '<div class="sidebarDivider"></div>';
 
         if (user.localUser && (AppInfo.isNativeApp && browserInfo.android)) {
-            html += '<a class="sidebarLink lnkMediaFolder lnkMySettings" onclick="return LibraryMenu.onLinkClicked(event, this);" href="mypreferencesmenu.html?userId=' + user.localUser.Id + '"><i class="md-icon sidebarLinkIcon">settings</i><span class="sidebarLinkText">' + Globalize.translate('ButtonSettings') + '</span></a>';
+            html += '<a class="sidebarLink lnkMediaFolder lnkMySettings" onclick="return LibraryMenu.onLinkClicked(event, this);" href="mypreferencesmenu.html"><i class="md-icon sidebarLinkIcon">settings</i><span class="sidebarLinkText">' + Globalize.translate('ButtonSettings') + '</span></a>';
         }
 
         html += '<a class="sidebarLink lnkMediaFolder lnkManageOffline" data-itemid="manageoffline" onclick="return LibraryMenu.onLinkClicked(event, this);" href="mysync.html?mode=offline"><i class="md-icon sidebarLinkIcon">file_download</i><span class="sidebarLinkText">' + Globalize.translate('ManageOfflineDownloads') + '</span></a>';
@@ -331,11 +353,13 @@
 
     function refreshDashboardInfoInDrawer(page, user) {
 
-        if (!navDrawerScrollContainer.querySelector('.adminDrawerLogo')) {
-            createDashboardMenu(page);
-        } else {
-            updateDashboardMenuSelectedItem();
-        }
+        loadNavDrawer().then(function () {
+            if (!navDrawerScrollContainer.querySelector('.adminDrawerLogo')) {
+                createDashboardMenu(page);
+            } else {
+                updateDashboardMenuSelectedItem();
+            }
+        });
     }
 
     function updateDashboardMenuSelectedItem() {
@@ -361,9 +385,7 @@
                 var secondaryTitle = (link.innerText || link.textContent).trim();
                 title += secondaryTitle;
 
-                var documentTitle = secondaryTitle;
-
-                Dashboard.setPageTitle(title, documentTitle);
+                LibraryMenu.setTitle(title);
 
             } else {
                 link.classList.remove('selectedSidebarLink');
@@ -456,11 +478,13 @@
             showBySelector('.lnkSyncToOtherDevices', false);
         }
 
-        if (user.Policy.EnableSync && appHost.supports('sync')) {
-            showBySelector('.lnkManageOffline', true);
-        } else {
-            showBySelector('.lnkManageOffline', false);
-        }
+        require(['apphost'], function (appHost) {
+            if (user.Policy.EnableSync && appHost.supports('sync')) {
+                showBySelector('.lnkManageOffline', true);
+            } else {
+                showBySelector('.lnkManageOffline', false);
+            }
+        });
 
         var userId = Dashboard.getCurrentUserId();
 
@@ -684,7 +708,7 @@
                 var helpUrl = page.getAttribute('data-helpurl');
 
                 if (helpUrl) {
-                    html += '<a href="' + helpUrl + '" target="_blank" class="clearLink" style="margin-left:2em;" title="' + Globalize.translate('ButtonHelp') + '"><button is="emby-button" type="button" class="accent" style="margin:0;font-weight:normal;font-size:14px;padding:.25em;display:block;align-items:center;"><i class="md-icon">info</i><span>' + Globalize.translate('ButtonHelp') + '</span></button></a>';
+                    html += '<a href="' + helpUrl + '" target="_blank" class="clearLink" style="margin-left:2em;" title="' + Globalize.translate('ButtonHelp') + '"><button is="emby-button" type="button" class="button-accent-flat button-flat" style="margin:0;font-weight:normal;font-size:14px;padding:.25em;display:block;align-items:center;"><i class="md-icon">info</i><span>' + Globalize.translate('ButtonHelp') + '</span></button></a>';
                 }
             }
 
@@ -692,33 +716,10 @@
             if (libraryMenuButtonText) {
                 libraryMenuButtonText.innerHTML = html;
             }
+
+            document.title = title || 'Emby';
         },
 
-        setBackButtonVisible: function (visible) {
-
-            var backButton = document.querySelector('.headerBackButton');
-
-            if (backButton) {
-                if (visible) {
-                    backButton.classList.remove('hide');
-                } else {
-                    backButton.classList.add('hide');
-                }
-            }
-        },
-
-        setMenuButtonVisible: function (visible) {
-
-            var mainDrawerButton = document.querySelector('.mainDrawerButton');
-
-            if (mainDrawerButton) {
-                if (!visible && browserInfo.mobile) {
-                    mainDrawerButton.classList.remove('hide');
-                } else {
-                    mainDrawerButton.classList.remove('hide');
-                }
-            }
-        },
         setTransparentMenu: function (transparent) {
 
             var viewMenuBar = document.querySelector('.viewMenuBar');
@@ -743,20 +744,19 @@
             return;
         }
 
-        var info = MediaController.getPlayerInfo();
+        var info = playbackManager.getPlayerInfo();
 
-        if (info.isLocalPlayer) {
-
-            btnCast.querySelector('i').innerHTML = 'cast';
-            btnCast.classList.remove('btnActiveCast');
-
-            context.querySelector('.headerSelectedPlayer').innerHTML = '';
-
-        } else {
+        if (info && !info.isLocalPlayer) {
 
             btnCast.querySelector('i').icon = 'cast_connected';
             btnCast.classList.add('btnActiveCast');
             context.querySelector('.headerSelectedPlayer').innerHTML = info.deviceName || info.name;
+
+        } else {
+            btnCast.querySelector('i').innerHTML = 'cast';
+            btnCast.classList.remove('btnActiveCast');
+
+            context.querySelector('.headerSelectedPlayer').innerHTML = '';
         }
     }
 
@@ -861,9 +861,21 @@
         var isDashboardPage = page.classList.contains('type-interior');
 
         if (isDashboardPage) {
+            if (mainDrawerButton) {
+                mainDrawerButton.classList.remove('hide');
+            }
             refreshDashboardInfoInDrawer(page);
         } else {
-            if (navDrawerElement.classList.contains('adminDrawer')) {
+
+            if (mainDrawerButton) {
+                if (enableLibraryNavDrawer) {
+                    mainDrawerButton.classList.remove('hide');
+                } else {
+                    mainDrawerButton.classList.add('hide');
+                }
+            }
+
+            if ((navDrawerElement && navDrawerElement.classList.contains('adminDrawer')) || (!navDrawerElement && enableLibraryNavDrawer)) {
                 refreshLibraryDrawer();
             }
         }
@@ -903,15 +915,8 @@
     });
 
     function updateTitle(page) {
-        var title = page.getAttribute('data-title') || page.getAttribute('data-contextname');
 
-        if (!title) {
-            var titleKey = getParameterByName('titlekey');
-
-            if (titleKey) {
-                title = Globalize.translate(titleKey);
-            }
-        }
+        var title = page.getAttribute('data-title');
 
         if (title) {
             LibraryMenu.setTitle(title);
@@ -920,18 +925,10 @@
 
     function updateBackButton(page) {
 
-        var canGoBack = !page.classList.contains('homePage') && history.length > 0;
-
         var backButton = document.querySelector('.headerBackButton');
 
-        var showBackButton = AppInfo.enableBackButton;
-
-        if (!showBackButton) {
-            showBackButton = page.getAttribute('data-backbutton') == 'true';
-        }
-
         if (backButton) {
-            if (canGoBack && showBackButton) {
+            if (page.getAttribute('data-backbutton') == 'true' && embyRouter.canGoBack()) {
                 backButton.classList.remove('hide');
             } else {
                 backButton.classList.add('hide');
@@ -941,10 +938,6 @@
 
     function initHeadRoom(elem) {
 
-        if (!AppInfo.enableHeadRoom) {
-            return;
-        }
-
         require(["headroom-window"], function (headroom) {
 
             headroom.add(elem);
@@ -974,24 +967,34 @@
             admin = true;
         }
 
-        if (admin) {
-            navDrawerElement.classList.add('adminDrawer');
-            navDrawerElement.classList.remove('darkDrawer');
-        } else {
-            navDrawerElement.classList.add('darkDrawer');
-            navDrawerElement.classList.remove('adminDrawer');
+        var enableNavDrawer = admin || enableLibraryNavDrawer;
+        if (enableNavDrawer) {
+            loadNavDrawer().then(function () {
+                if (admin) {
+                    navDrawerElement.classList.add('adminDrawer');
+                    navDrawerElement.classList.remove('darkDrawer');
+                } else {
+                    navDrawerElement.classList.add('darkDrawer');
+                    navDrawerElement.classList.remove('adminDrawer');
+                }
+            });
         }
     }
 
     function refreshLibraryDrawer(user) {
 
-        var promise = user ? Promise.resolve(user) : ConnectionManager.user(window.ApiClient);
+        if (!enableLibraryNavDrawer) {
+            return;
+        }
 
-        promise.then(function (user) {
-            refreshLibraryInfoInDrawer(user);
+        loadNavDrawer().then(function () {
+            var promise = user ? Promise.resolve(user) : ConnectionManager.user(window.ApiClient);
 
-            document.dispatchEvent(new CustomEvent("libraryMenuCreated", {}));
-            updateLibraryMenu(user.localUser);
+            promise.then(function (user) {
+                refreshLibraryInfoInDrawer(user);
+
+                updateLibraryMenu(user.localUser);
+            });
         });
     }
 
@@ -1001,7 +1004,7 @@
         // At least 240
         drawerWidth = Math.max(drawerWidth, 240);
         // But not exceeding 280
-        drawerWidth = Math.min(drawerWidth, 280);
+        drawerWidth = Math.min(drawerWidth, 260);
 
         var disableEdgeSwipe = false;
 
@@ -1020,8 +1023,25 @@
         };
     }
 
-    navDrawerInstance = new navdrawer(getNavDrawerOptions());
-    navDrawerElement.classList.remove('hide');
+    function loadNavDrawer() {
+
+        if (navDrawerInstance) {
+            return Promise.resolve(navDrawerInstance);
+        }
+
+        return new Promise(function (resolve, reject) {
+
+            navDrawerElement = document.querySelector('.mainDrawer');
+            navDrawerScrollContainer = navDrawerElement.querySelector('.scrollContainer');
+
+            require(['navdrawer'], function (navdrawer) {
+                navDrawerInstance = new navdrawer(getNavDrawerOptions());
+                navDrawerElement.classList.remove('hide');
+                resolve(navDrawerInstance);
+            });
+        });
+    }
+
     renderHeader();
 
     Events.on(ConnectionManager, 'apiclientcreated', function (e, apiClient) {
@@ -1037,13 +1057,17 @@
     });
 
     Events.on(ConnectionManager, 'localusersignedout', updateUserInHeader);
-    Events.on(MediaController, 'playerchange', updateCastIcon);
+    Events.on(playbackManager, 'playerchange', updateCastIcon);
 
     setDrawerClass();
 
-    //require(['appfooter-shared', 'dockedtabs'], function (footer, dockedtabs) {
-    //    new dockedtabs({
-    //        appFooter: footer
-    //    });
-    //});
+    if (enableBottomTabs) {
+        require(['appfooter-shared', 'dockedtabs'], function (footer, dockedtabs) {
+            new dockedtabs({
+                appFooter: footer
+            });
+        });
+    }
+
+    return LibraryMenu;
 });
\ No newline at end of file
