@@ -1,12 +1,9 @@
-﻿define(['appSettings'], function (appSettings) {
+﻿define(['appSettings', 'connectionManager'], function (appSettings, connectionManager) {
+    'use strict';
 
     var syncPromise;
 
-    window.LocalSync = {
-
-        isSupported: function () {
-            return AppInfo.isNativeApp && Dashboard.capabilities().SupportsSync;
-        },
+    return {
 
         sync: function (options) {
 
@@ -16,15 +13,13 @@
 
             return new Promise(function (resolve, reject) {
 
-                require(['multiserversync'], function () {
+                require(['multiserversync'], function (MultiServerSync) {
 
                     options = options || {};
 
-                    LocalSync.normalizeSyncOptions(options);
-
                     options.cameraUploadServers = appSettings.cameraUploadServers();
 
-                    syncPromise = new MediaBrowser.MultiServerSync(ConnectionManager).sync(options).then(function () {
+                    syncPromise = new MultiServerSync(connectionManager).sync(options).then(function () {
 
                         syncPromise = null;
                         resolve();
@@ -38,10 +33,6 @@
             });
         },
 
-        normalizeSyncOptions: function (options) {
-
-        },
-
         getSyncStatus: function () {
 
             if (syncPromise != null) {
