@@ -1,7 +1,46 @@
-﻿(function ($, document, window) {
+﻿define(['jQuery', 'dom', 'listViewStyle'], function ($, dom) {
+    'use strict';
 
     var currentType;
 
+    function populateLanguages(select) {
+
+        return ApiClient.getCultures().then(function (languages) {
+
+            var html = "";
+
+            html += "<option value=''></option>";
+
+            for (var i = 0, length = languages.length; i < length; i++) {
+
+                var culture = languages[i];
+
+                html += "<option value='" + culture.TwoLetterISOLanguageName + "'>" + culture.DisplayName + "</option>";
+            }
+
+            select.innerHTML = html;
+        });
+    }
+
+    function populateCountries(select) {
+
+        return ApiClient.getCountries().then(function (allCountries) {
+
+            var html = "";
+
+            html += "<option value=''></option>";
+
+            for (var i = 0, length = allCountries.length; i < length; i++) {
+
+                var culture = allCountries[i];
+
+                html += "<option value='" + culture.TwoLetterISORegionName + "'>" + culture.DisplayName + "</option>";
+            }
+
+            select.innerHTML = html;
+        });
+    }
+
     function loadTabs(page, tabs) {
 
         var html = '';
@@ -89,19 +128,20 @@
         $('.imageType', page).each(function () {
 
             var imageType = this.getAttribute('data-imagetype');
+            var container = dom.parentWithTag(this, 'LABEL');
 
             if (metadataInfo.SupportedImageTypes.indexOf(imageType) == -1) {
-                $(this).hide();
+                container.classList.add('hide');
             } else {
-                $(this).show();
+                container.classList.remove('hide');
             }
 
             if (getImageConfig(config, imageType).Limit) {
 
-                $('input', this).checked(true).checkboxradio('refresh');
+                this.checked = true;
 
             } else {
-                $('input', this).checked(false).checkboxradio('refresh');
+                this.checked = false;
             }
         });
 
@@ -144,80 +184,66 @@
         var html = '';
 
         if (!plugins.length) {
-            $('.imageFetchers', page).html(html).hide().trigger('create');
+            $('.imageFetchers', page).html(html).hide();
             return;
         }
 
         var i, length, plugin, id;
 
-        html += '<div class="ui-controlgroup-label" style="margin-bottom:0;padding-left:2px;">' + Globalize.translate('LabelImageFetchers') + '</div>';
-
-        html += '<div style="display:inline-block;width: 75%;vertical-align:top;">';
-        html += '<div data-role="controlgroup" class="imageFetcherGroup">';
+        html += '<h3 class="checkboxListLabel">' + Globalize.translate('LabelImageFetchers') + '</h3>';
+        html += '<div class="checkboxList paperList checkboxList-paperList">';
 
         for (i = 0, length = plugins.length; i < length; i++) {
 
             plugin = plugins[i];
 
-            id = 'chkImageFetcher' + i;
-
             var isChecked = config.DisabledImageFetchers.indexOf(plugin.Name) == -1 ? ' checked="checked"' : '';
 
-            html += '<input class="chkImageFetcher" type="checkbox" name="' + id + '" id="' + id + '" data-pluginname="' + plugin.Name + '" data-mini="true"' + isChecked + '>';
-            html += '<label for="' + id + '">' + plugin.Name + '</label>';
+            html += '<div class="listItem imageFetcherItem" data-pluginname="' + plugin.Name + '">';
+
+            html += '<label class="listItemCheckboxContainer"><input type="checkbox" is="emby-checkbox" class="chkImageFetcher" data-pluginname="' + plugin.Name + '" ' + isChecked + '><span></span></label>';
+
+            html += '<div class="listItemBody">';
+
+            html += '<h3 class="listItemBodyText">';
+            html += plugin.Name;
+            html += '</h3>';
+
+            html += '</div>';
+
+            html += '<button type="button" is="paper-icon-button-light" title="' + Globalize.translate('ButtonUp') + '" class="btnUp" style="padding:3px 8px;"><i class="md-icon">keyboard_arrow_up</i></button>';
+            html += '<button type="button" is="paper-icon-button-light" title="' + Globalize.translate('ButtonDown') + '" class="btnDown" style="padding:3px 8px;"><i class="md-icon">keyboard_arrow_down</i></button>';
+
+            html += '</div>';
         }
 
         html += '</div>';
-        html += '</div>';
+        html += '<div class="fieldDescription">' + Globalize.translate('LabelImageFetchersHelp') + '</div>';
 
-        if (plugins.length > 1) {
-            html += '<div style="display:inline-block;vertical-align:top;margin-left:5px;">';
-
-            for (i = 0, length = plugins.length; i < length; i++) {
-
-                html += '<div>';
-
-                if (i > 0) {
-                    html += '<paper-icon-button class="btnUp" data-pluginindex="' + i + '" icon="keyboard-arrow-up" title="' + Globalize.translate('ButtonUp') + '" style="padding:3px 8px;"></paper-icon-button>';
-                } else {
-                    html += '<paper-icon-button disabled class="btnUp" data-pluginindex="' + i + '" icon="keyboard-arrow-up" title="' + Globalize.translate('ButtonUp') + '" style="padding:3px 8px;"></paper-icon-button>';
-                }
-
-                if (i < (plugins.length - 1)) {
-                    html += '<paper-icon-button class="btnDown" data-pluginindex="' + i + '" icon="keyboard-arrow-down" title="' + Globalize.translate('ButtonDown') + '" style="padding:3px 8px;"></paper-icon-button>';
-                } else {
-                    html += '<paper-icon-button disabled class="btnDown" data-pluginindex="' + i + '" icon="keyboard-arrow-down" title="' + Globalize.translate('ButtonDown') + '" style="padding:3px 8px;"></paper-icon-button>';
-                }
-                html += '</div>';
-            }
-        }
-
-        html += '</div>';
-        html += '<div class="fieldDescription" style="width:75%;">' + Globalize.translate('LabelImageFetchersHelp') + '</div>';
-
-        var elem = $('.imageFetchers', page).html(html).show().trigger('create');
+        var elem = $('.imageFetchers', page).html(html).show();
 
         $('.btnDown', elem).on('click', function () {
-            var index = parseInt(this.getAttribute('data-pluginindex'));
 
-            var elemToMove = $('.imageFetcherGroup .ui-checkbox', page)[index];
+            var elemToMove = $(this).parents('.imageFetcherItem')[0];
 
-            var insertAfter = $(elemToMove).next('.ui-checkbox')[0];
+            var insertAfter = $(elemToMove).next('.imageFetcherItem')[0];
 
-            elemToMove.parentNode.removeChild(elemToMove);
-            $(elemToMove).insertAfter(insertAfter);
+            if (insertAfter) {
+                elemToMove.parentNode.removeChild(elemToMove);
+                $(elemToMove).insertAfter(insertAfter);
+            }
         });
 
         $('.btnUp', elem).on('click', function () {
 
-            var index = parseInt(this.getAttribute('data-pluginindex'));
+            var elemToMove = $(this).parents('.imageFetcherItem')[0];
 
-            var elemToMove = $('.imageFetcherGroup .ui-checkbox', page)[index];
+            var insertBefore = $(elemToMove).prev('.imageFetcherItem')[0];
 
-            var insertBefore = $(elemToMove).prev('.ui-checkbox')[0];
-
-            elemToMove.parentNode.removeChild(elemToMove);
-            $(elemToMove).insertBefore(insertBefore);
+            if (insertBefore) {
+                elemToMove.parentNode.removeChild(elemToMove);
+                $(elemToMove).insertBefore(insertBefore);
+            }
         });
     }
 
@@ -230,29 +256,26 @@
         var html = '';
 
         if (!plugins.length) {
-            $('.metadataSavers', page).html(html).hide().trigger('create');
+            $('.metadataSavers', page).html(html).hide();
             return;
         }
 
-        html += '<fieldset data-role="controlgroup">';
-        html += '<legend>' + Globalize.translate('LabelMetadataSavers') + '</legend>';
+        html += '<h3 class="checkboxListLabel">' + Globalize.translate('LabelMetadataSavers') + '</h3>';
+        html += '<div class="checkboxList paperList checkboxList-paperList">';
 
         for (var i = 0, length = plugins.length; i < length; i++) {
 
             var plugin = plugins[i];
 
-            var id = 'chkMetadataSaver' + i;
-
             var isChecked = config.DisabledMetadataSavers.indexOf(plugin.Name) == -1 ? ' checked="checked"' : '';
 
-            html += '<input class="chkMetadataSaver" type="checkbox" name="' + id + '" id="' + id + '" data-mini="true"' + isChecked + ' data-pluginname="' + plugin.Name + '">';
-            html += '<label for="' + id + '">' + plugin.Name + '</label>';
+            html += '<label><input type="checkbox" is="emby-checkbox" class="chkMetadataSaver" data-pluginname="' + plugin.Name + '" ' + isChecked + '><span>' + plugin.Name + '</span></label>';
         }
 
-        html += '</fieldset>';
-        html += '<div class="fieldDescription">' + Globalize.translate('LabelMetadataSaversHelp') + '</div>';
+        html += '</div>';
+        html += '<div class="fieldDescription" style="margin-top:.25em;">' + Globalize.translate('LabelMetadataSaversHelp') + '</div>';
 
-        $('.metadataSavers', page).html(html).show().trigger('create');
+        page.querySelector('.metadataSavers').innerHTML = html;
     }
 
     function renderMetadataFetchers(page, type, config, metadataInfo) {
@@ -264,80 +287,66 @@
         var html = '';
 
         if (!plugins.length) {
-            $('.metadataFetchers', page).html(html).hide().trigger('create');
+            $('.metadataFetchers', page).html(html).hide();
             return;
         }
 
-        var i, length, plugin, id;
+        var i, length, plugin;
 
-        html += '<div class="ui-controlgroup-label" style="margin-bottom:0;padding-left:2px;">' + Globalize.translate('LabelMetadataDownloaders') + '</div>';
-
-        html += '<div style="display:inline-block;width: 75%;vertical-align:top;">';
-        html += '<div data-role="controlgroup" class="metadataFetcherGroup">';
+        html += '<h3 class="checkboxListLabel">' + Globalize.translate('LabelMetadataDownloaders') + '</h3>';
+        html += '<div class="checkboxList paperList checkboxList-paperList">';
 
         for (i = 0, length = plugins.length; i < length; i++) {
 
             plugin = plugins[i];
 
-            id = 'chkMetadataFetcher' + i;
-
             var isChecked = config.DisabledMetadataFetchers.indexOf(plugin.Name) == -1 ? ' checked="checked"' : '';
 
-            html += '<input class="chkMetadataFetcher" type="checkbox" name="' + id + '" id="' + id + '" data-pluginname="' + plugin.Name + '" data-mini="true"' + isChecked + '>';
-            html += '<label for="' + id + '">' + plugin.Name + '</label>';
+            html += '<div class="listItem metadataFetcherItem" data-pluginname="' + plugin.Name + '">';
+
+            html += '<label class="listItemCheckboxContainer"><input type="checkbox" is="emby-checkbox" class="chkMetadataFetcher" data-pluginname="' + plugin.Name + '" ' + isChecked + '><span></span></label>';
+
+            html += '<div class="listItemBody">';
+
+            html += '<h3 class="listItemBodyText">';
+            html += plugin.Name;
+            html += '</h3>';
+
+            html += '</div>';
+
+            html += '<button type="button" is="paper-icon-button-light" title="' + Globalize.translate('ButtonUp') + '" class="btnUp" style="padding:3px 8px;"><i class="md-icon">keyboard_arrow_up</i></button>';
+            html += '<button type="button" is="paper-icon-button-light" title="' + Globalize.translate('ButtonDown') + '" class="btnDown" style="padding:3px 8px;"><i class="md-icon">keyboard_arrow_down</i></button>';
+
+            html += '</div>';
         }
 
         html += '</div>';
-        html += '</div>';
+        html += '<div class="fieldDescription">' + Globalize.translate('LabelMetadataDownloadersHelp') + '</div>';
 
-        if (plugins.length > 1) {
-            html += '<div style="display:inline-block;vertical-align:top;margin-left:5px;">';
-
-            for (i = 0, length = plugins.length; i < length; i++) {
-
-                html += '<div>';
-
-                if (i > 0) {
-                    html += '<paper-icon-button class="btnUp" data-pluginindex="' + i + '" icon="keyboard-arrow-up" title="' + Globalize.translate('ButtonUp') + '" style="padding:3px 8px;"></paper-icon-button>';
-                } else {
-                    html += '<paper-icon-button disabled class="btnUp" data-pluginindex="' + i + '" icon="keyboard-arrow-up" title="' + Globalize.translate('ButtonUp') + '" style="padding:3px 8px;"></paper-icon-button>';
-                }
-
-                if (i < (plugins.length - 1)) {
-                    html += '<paper-icon-button class="btnDown" data-pluginindex="' + i + '" icon="keyboard-arrow-down" title="' + Globalize.translate('ButtonDown') + '" style="padding:3px 8px;"></paper-icon-button>';
-                } else {
-                    html += '<paper-icon-button disabled class="btnDown" data-pluginindex="' + i + '" icon="keyboard-arrow-down" title="' + Globalize.translate('ButtonDown') + '" style="padding:3px 8px;"></paper-icon-button>';
-                }
-                html += '</div>';
-            }
-        }
-
-        html += '</div>';
-        html += '<div class="fieldDescription" style="width:75%;">' + Globalize.translate('LabelMetadataDownloadersHelp') + '</div>';
-
-        var elem = $('.metadataFetchers', page).html(html).show().trigger('create');
+        var elem = $('.metadataFetchers', page).html(html).show();
 
         $('.btnDown', elem).on('click', function () {
-            var index = parseInt(this.getAttribute('data-pluginindex'));
 
-            var elemToMove = $('.metadataFetcherGroup .ui-checkbox', page)[index];
+            var elemToMove = $(this).parents('.metadataFetcherItem')[0];
 
-            var insertAfter = $(elemToMove).next('.ui-checkbox')[0];
+            var insertAfter = $(elemToMove).next('.metadataFetcherItem')[0];
 
-            elemToMove.parentNode.removeChild(elemToMove);
-            $(elemToMove).insertAfter(insertAfter);
+            if (insertAfter) {
+                elemToMove.parentNode.removeChild(elemToMove);
+                $(elemToMove).insertAfter(insertAfter);
+            }
         });
 
         $('.btnUp', elem).on('click', function () {
 
-            var index = parseInt(this.getAttribute('data-pluginindex'));
+            var elemToMove = $(this).parents('.metadataFetcherItem')[0];
 
-            var elemToMove = $('.metadataFetcherGroup .ui-checkbox', page)[index];
+            var insertBefore = $(elemToMove).prev('.metadataFetcherItem')[0];
 
-            var insertBefore = $(elemToMove).prev('.ui-checkbox')[0];
-
-            elemToMove.parentNode.removeChild(elemToMove);
-            $(elemToMove).insertBefore(insertBefore);
+            if (insertBefore) {
+                elemToMove.parentNode.removeChild(elemToMove);
+                $(elemToMove).insertBefore(insertBefore);
+            }
         });
     }
 
@@ -350,46 +359,61 @@
         var html = '';
 
         if (plugins.length < 2) {
-            $('.metadataReaders', page).html(html).hide().trigger('create');
+            $('.metadataReaders', page).html(html).hide();
             return;
         }
 
-        html += '<div class="ui-controlgroup-label" style="margin-bottom:0;padding-left:2px;">' + Globalize.translate('LabelMetadataReaders') + '</div>';
-        html += '<ul data-role="listview" data-inset="true" data-mini="true" style="margin-top:.5em;margin-bottom:.5em;">';
+        html += '<h3 class="checkboxListLabel">' + Globalize.translate('LabelMetadataReaders') + '</h3>';
+        html += '<div class="checkboxList paperList checkboxList-paperList">';
 
         for (var i = 0, length = plugins.length; i < length; i++) {
 
             var plugin = plugins[i];
 
-            html += '<li data-mini="true" class="localReaderOption" data-pluginname="' + plugin.Name + '">';
+            html += '<div class="listItem localReaderOption" data-pluginname="' + plugin.Name + '">';
+
+            html += '<i class="listItemIcon md-icon">live_tv</i>';
+
+            html += '<div class="listItemBody">';
+
+            html += '<h3 class="listItemBodyText">';
+            html += plugin.Name;
+            html += '</h3>';
+
+            html += '</div>';
 
             if (i > 0) {
-                html += '<a href="#" style="font-size:13px;font-weight:normal;">' + plugin.Name + '</a>';
-
-                html += '<a class="btnLocalReaderUp btnLocalReaderMove" data-pluginindex="' + i + '" href="#" style="font-size:13px;font-weight:normal;" data-icon="arrow-u">' + Globalize.translate('ButtonUp') + '</a>';
+                html += '<button type="button" is="paper-icon-button-light" title="' + Globalize.translate('ButtonUp') + '" class="btnLocalReaderUp btnLocalReaderMove" data-pluginindex="' + i + '"><i class="md-icon">keyboard_arrow_up</i></button>';
             }
             else if (plugins.length > 1) {
 
-                html += '<a href="#" style="font-size:13px;font-weight:normal;">' + plugin.Name + '</a>';
-
-                html += '<a class="btnLocalReaderDown btnLocalReaderMove" data-pluginindex="' + i + '" href="#" style="font-size:13px;font-weight:normal;" data-icon="arrow-d">' + Globalize.translate('ButtonDown') + '</a>';
+                html += '<button type="button" is="paper-icon-button-light" title="' + Globalize.translate('ButtonDown') + '" class="btnLocalReaderDown btnLocalReaderMove" data-pluginindex="' + i + '"><i class="md-icon">keyboard_arrow_down</i></button>';
             }
-            else {
 
-                html += plugin.Name;
-
-            }
-            html += '</li>';
+            html += '</div>';
         }
 
-        html += '</ul>';
+        html += '</div>';
         html += '<div class="fieldDescription">' + Globalize.translate('LabelMetadataReadersHelp') + '</div>';
 
-        $('.metadataReaders', page).html(html).show().trigger('create');
+        $('.metadataReaders', page).html(html).show();
     }
 
     function loadPage(page) {
 
+        var promises = [
+          ApiClient.getServerConfiguration(),
+          populateLanguages(page.querySelector('#selectLanguage')),
+          populateCountries(page.querySelector('#selectCountry'))
+        ];
+
+        Promise.all(promises).then(function (responses) {
+
+            var config = responses[0];
+            page.querySelector('#selectLanguage').value = config.PreferredMetadataLanguage || '';
+            page.querySelector('#selectCountry').value = config.MetadataCountryCode || '';
+        });
+
         loadTabs(page, [
 
             { name: 'OptionMovies', type: 'Movie' },
@@ -416,7 +440,11 @@
 
     function saveSettingsIntoConfig(form, config) {
 
-        config.DisabledMetadataSavers = $('.chkMetadataSaver:not(:checked)', form).get().map(function (c) {
+        config.DisabledMetadataSavers = $('.chkMetadataSaver', form).get().filter(function (c) {
+
+            return !c.checked;
+
+        }).map(function (c) {
 
             return c.getAttribute('data-pluginname');
 
@@ -428,7 +456,9 @@
 
         });
 
-        config.DisabledMetadataFetchers = $('.chkMetadataFetcher:not(:checked)', form).get().map(function (c) {
+        config.DisabledMetadataFetchers = $('.chkMetadataFetcher', form).get().filter(function (c) {
+            return !c.checked;
+        }).map(function (c) {
 
             return c.getAttribute('data-pluginname');
 
@@ -440,7 +470,9 @@
 
         });
 
-        config.DisabledImageFetchers = $('.chkImageFetcher:not(:checked)', form).get().map(function (c) {
+        config.DisabledImageFetchers = $('.chkImageFetcher', form).get().filter(function (c) {
+            return !c.checked;
+        }).map(function (c) {
 
             return c.getAttribute('data-pluginname');
 
@@ -452,11 +484,11 @@
 
         });
 
-        config.ImageOptions = $('.imageType:visible input', form).get().map(function (c) {
+        config.ImageOptions = $('.imageType:not(.hide)', form).get().map(function (c) {
 
 
             return {
-                Type: $(c).parents('.imageType').attr('data-imagetype'),
+                Type: c.getAttribute('data-imagetype'),
                 Limit: c.checked ? 1 : 0,
                 MinWidth: 0
             };
@@ -492,6 +524,9 @@
 
             if (metadataOptions) {
 
+                config.PreferredMetadataLanguage = form.querySelector('#selectLanguage').value;
+                config.MetadataCountryCode = form.querySelector('#selectCountry').value;
+
                 saveSettingsIntoConfig(form, metadataOptions);
                 ApiClient.updateServerConfiguration(config).then(Dashboard.processServerConfigurationUpdateResult);
 
@@ -512,6 +547,30 @@
         return false;
     }
 
+    function getTabs() {
+        return [
+        {
+            href: 'library.html',
+            name: Globalize.translate('HeaderLibraries')
+        },
+         {
+             href: 'librarydisplay.html',
+             name: Globalize.translate('TabDisplay')
+         },
+         {
+             href: 'metadataimages.html',
+             name: Globalize.translate('TabMetadata')
+         },
+         {
+             href: 'metadatanfo.html',
+             name: Globalize.translate('TabNfoSettings')
+         },
+         {
+             href: 'librarysettings.html',
+             name: Globalize.translate('TabAdvanced')
+         }];
+    }
+
     $(document).on('pageinit', "#metadataImagesConfigurationPage", function () {
 
         var page = this;
@@ -519,7 +578,7 @@
         $('.metadataReaders', page).on('click', '.btnLocalReaderMove', function () {
 
             var li = $(this).parents('.localReaderOption');
-            var ul = li.parents('ul');
+            var list = li.parents('.paperList');
 
             if ($(this).hasClass('btnLocalReaderDown')) {
 
@@ -534,12 +593,12 @@
                 li.remove().insertBefore(prev);
             }
 
-            $('.localReaderOption', ul).each(function () {
+            $('.localReaderOption', list).each(function () {
 
                 if ($(this).prev('.localReaderOption').length) {
-                    $('.btnLocalReaderMove', this).addClass('btnLocalReaderUp').removeClass('btnLocalReaderDown').attr('data-icon', 'arrow-u').removeClass('ui-icon-arrow-d').addClass('ui-icon-arrow-u');
+                    $('.btnLocalReaderMove', this).addClass('btnLocalReaderUp').removeClass('btnLocalReaderDown').attr('icon', 'keyboard-arrow-up');
                 } else {
-                    $('.btnLocalReaderMove', this).addClass('btnLocalReaderDown').removeClass('btnLocalReaderUp').attr('data-icon', 'arrow-d').removeClass('ui-icon-arrow-u').addClass('ui-icon-arrow-d');
+                    $('.btnLocalReaderMove', this).addClass('btnLocalReaderDown').removeClass('btnLocalReaderUp').attr('icon', 'keyboard-arrow-down');
                 }
 
             });
@@ -554,6 +613,7 @@
 
     }).on('pageshow', "#metadataImagesConfigurationPage", function () {
 
+        LibraryMenu.setTabs('metadata', 2, getTabs);
         Dashboard.showLoadingMsg();
 
         var page = this;
@@ -561,4 +621,4 @@
         loadPage(page);
     });
 
-})(jQuery, document, window);
\ No newline at end of file
+});
\ No newline at end of file
