@@ -1,4 +1,5 @@
-﻿define(['jQuery'], function ($) {
+﻿define(['jQuery', 'cardBuilder', 'imageLoader', 'emby-itemscontainer'], function ($, cardBuilder, imageLoader) {
+    'use strict';
 
     var view = 'Poster';
 
@@ -13,7 +14,7 @@
                 query: {
                     SortBy: "IsFolder,SortName",
                     SortOrder: "Ascending",
-                    Fields: "PrimaryImageAspectRatio,SortName,SyncInfo",
+                    Fields: "PrimaryImageAspectRatio,SortName",
                     ImageTypeLimit: 1,
                     EnableImageTypes: "Primary",
                     StartIndex: 0,
@@ -58,7 +59,7 @@
 
             if (view == "Poster") {
                 // Poster
-                html = LibraryBrowser.getPosterViewHtml({
+                html = cardBuilder.getCardsHtml({
                     items: result.Items,
                     shape: "square",
                     context: getParameterByName('context') || 'photos',
@@ -72,7 +73,7 @@
 
             var elem = page.querySelector('.itemsContainer');
             elem.innerHTML = html + pagingHtml;
-            ImageLoader.lazyChildren(elem);
+            imageLoader.lazyChildren(elem);
 
             $('.btnNextPage', page).on('click', function () {
                 query.StartIndex += query.Limit;
