@@ -1,31 +1,20 @@
-﻿define(['libraryBrowser', 'cardBuilder', 'appSettings', 'components/groupedcards', 'dom', 'scrollStyles', 'emby-button', 'paper-icon-button-light', 'emby-itemscontainer'], function (libraryBrowser, cardBuilder, appSettings, groupedcards, dom) {
+﻿define(['libraryBrowser', 'cardBuilder', 'appSettings', 'components/groupedcards', 'dom', 'apphost', 'imageLoader', 'scrollStyles', 'emby-button', 'paper-icon-button-light', 'emby-itemscontainer'], function (libraryBrowser, cardBuilder, appSettings, groupedcards, dom, appHost, imageLoader) {
+    'use strict';
 
     function getUserViews(userId) {
 
         return ApiClient.getUserViews({}, userId).then(function (result) {
 
-            var items = result.Items;
-
-            var list = [];
-
-            for (var i = 0, length = items.length; i < length; i++) {
-
-                var view = items[i];
-
-                if (AppInfo.isNativeApp && browserInfo.safari && view.CollectionType == 'livetv') {
-                    continue;
-                }
-
-                list.push(view);
-            }
-
-            return list;
+            return result.Items;
         });
     }
 
     function enableScrollX() {
+        return browserInfo.mobile;
+    }
 
-        return browserInfo.mobile && AppInfo.enableAppLayouts;
+    function getSquareShape() {
+        return enableScrollX() ? 'overflowSquare' : 'square';
     }
 
     function getThumbShape() {
@@ -179,12 +168,6 @@
                 infos.push(getTheaterInfo);
             }
 
-            if (!AppInfo.enableAppLayouts) {
-                infos.push(getUpgradeMobileLayoutsInfo);
-            }
-
-            appSettings.set(cacheKey, new Date().getTime());
-
             return infos[getRandomInt(0, infos.length - 1)]();
         });
     }
@@ -217,10 +200,10 @@
 
         var html = '';
         html += '<div>';
-        html += '<h1>Try Emby Theater<button is="paper-icon-button-light" style="margin-left:1em;" onclick="this.parentNode.parentNode.remove();" class="autoSize"><i class="md-icon">close</i></button></h1>';
+        html += '<h1>Discover Emby Theater<button is="paper-icon-button-light" style="margin-left:1em;" onclick="this.parentNode.parentNode.remove();" class="autoSize"><i class="md-icon">close</i></button></h1>';
 
         var nameText = AppInfo.isNativeApp ? 'Emby Theater' : '<a href="https://emby.media/download" target="_blank">Emby Theater</a>';
-        html += '<p>A beautiful app for your TV and large screen tablet. ' + nameText + ' runs on Windows, Xbox One, Google Chrome, FireFox, Microsoft Edge and Opera.</p>';
+        html += '<p>A beautiful app for your TV and large screen tablet. ' + nameText + ' runs on Windows, Xbox One, Raspberry Pi, Samsung Smart TVs, Sony PS4, Web Browsers, and more.</p>';
         html += '<div class="itemsContainer vertical-wrap">';
         html += getCard('https://raw.githubusercontent.com/MediaBrowser/Emby.Resources/master/apps/theater1.png', 'https://emby.media/download');
         html += getCard('https://raw.githubusercontent.com/MediaBrowser/Emby.Resources/master/apps/theater2.png', 'https://emby.media/download');
@@ -235,7 +218,7 @@
 
         var html = '';
         html += '<div>';
-        html += '<h1>Try Emby Premiere<button is="paper-icon-button-light" style="margin-left:1em;" onclick="this.parentNode.parentNode.remove();" class="autoSize"><i class="md-icon">close</i></button></h1>';
+        html += '<h1>Discover Emby Premiere<button is="paper-icon-button-light" style="margin-left:1em;" onclick="this.parentNode.parentNode.remove();" class="autoSize"><i class="md-icon">close</i></button></h1>';
 
         var cardTarget = AppInfo.isNativeApp ? '' : 'https://emby.media/premiere';
         var learnMoreText = AppInfo.isNativeApp ? '' : '<a href="https://emby.media/premiere" target="_blank">Learn more</a>';
@@ -269,134 +252,106 @@
         return html;
     }
 
+    function renderLatestSection(elem, user, parent) {
+
+        var options = {
+
+            Limit: 12,
+            Fields: "PrimaryImageAspectRatio,BasicSyncInfo",
+            ImageTypeLimit: 1,
+            EnableImageTypes: "Primary,Backdrop,Thumb",
+            ParentId: parent.Id
+        };
+
+        return ApiClient.getJSON(ApiClient.getUrl('Users/' + user.Id + '/Items/Latest', options)).then(function (items) {
+
+            var html = '';
+
+            var scrollX = enableScrollX();
+
+            if (items.length) {
+
+                html += '<div>';
+                html += '<h1 style="display:inline-block; vertical-align:middle;" class="listHeader">' + Globalize.translate('LatestFromLibrary', parent.Name) + '</h1>';
+                html += '<a href="' + libraryBrowser.getHref(parent) + '" class="clearLink" style="margin-left:2em;"><button is="emby-button" type="button" class="raised more mini"><span>' + Globalize.translate('ButtonMore') + '</span></button></a>';
+                html += '</div>';
+
+                if (scrollX) {
+                    html += '<div is="emby-itemscontainer" class="hiddenScrollX itemsContainer">';
+                } else {
+                    html += '<div is="emby-itemscontainer" class="itemsContainer vertical-wrap">';
+                }
+
+                var viewType = parent.CollectionType;
+
+                var shape = viewType === 'movies' ?
+                    getPortraitShape() :
+                    viewType === 'music' ?
+                    getSquareShape() :
+                    getThumbShape();
+
+                var supportsImageAnalysis = appHost.supports('imageanalysis');
+                var cardLayout = supportsImageAnalysis && (viewType === 'music' || viewType === 'movies' || viewType === 'tvshows' || !viewType);
+
+                html += cardBuilder.getCardsHtml({
+                    items: items,
+                    shape: shape,
+                    preferThumb: viewType !== 'movies' && viewType !== 'music',
+                    showUnplayedIndicator: false,
+                    showChildCountIndicator: true,
+                    context: 'home',
+                    overlayText: false,
+                    centerText: !cardLayout,
+                    overlayPlayButton: viewType !== 'photos',
+                    allowBottomPadding: !enableScrollX() && !cardLayout,
+                    cardLayout: cardLayout,
+                    showTitle: viewType === 'music' || !viewType || (cardLayout && (viewType === 'movies' || viewType === 'tvshows')),
+                    showYear: cardLayout && viewType === 'movies',
+                    showSeriesYear: cardLayout && viewType === 'tvshows',
+                    showParentTitle: viewType === 'music' || !viewType || (cardLayout && (viewType === 'tvshows')),
+                    vibrant: supportsImageAnalysis && cardLayout,
+                    lines: 2
+                });
+                html += '</div>';
+            }
+
+            elem.innerHTML = html;
+            imageLoader.lazyChildren(elem);
+        });
+    }
+
     function loadRecentlyAdded(elem, user) {
 
-        var options = {
+        elem.classList.remove('homePageSection');
 
-            Limit: 20,
-            Fields: "PrimaryImageAspectRatio,BasicSyncInfo",
-            ImageTypeLimit: 1,
-            EnableImageTypes: "Primary,Backdrop,Thumb"
-        };
+        return getUserViews(user.Id).then(function (items) {
 
-        return ApiClient.getJSON(ApiClient.getUrl('Users/' + user.Id + '/Items/Latest', options)).then(function (items) {
+            var excludeViewTypes = ['playlists', 'livetv', 'boxsets', 'channels'];
+            var excludeItemTypes = ['Channel'];
 
-            var html = '';
+            for (var i = 0, length = items.length; i < length; i++) {
 
-            var cardLayout = false;
+                var item = items[i];
 
-            if (items.length) {
-                html += '<div>';
-                html += '<h1 class="listHeader">' + Globalize.translate('HeaderLatestMedia') + '</h1>';
-
-                html += '</div>';
-
-                html += '<div is="emby-itemscontainer" class="itemsContainer vertical-wrap">';
-
-                html += cardBuilder.getCardsHtml({
-                    items: items,
-                    preferThumb: true,
-                    shape: 'backdrop',
-                    showUnplayedIndicator: false,
-                    showChildCountIndicator: true,
-                    lazy: true,
-                    cardLayout: cardLayout,
-                    showTitle: cardLayout,
-                    showYear: cardLayout,
-                    showDetailsMenu: true,
-                    context: 'home'
-                });
-                html += '</div>';
-            }
-
-            elem.innerHTML = html;
-            elem.addEventListener('click', groupedcards.onItemsContainerClick);
-            ImageLoader.lazyChildren(elem);
-        });
-    }
-
-    function loadLatestMovies(elem, user) {
-
-        var options = {
-
-            Limit: 12,
-            Fields: "PrimaryImageAspectRatio,BasicSyncInfo",
-            ImageTypeLimit: 1,
-            EnableImageTypes: "Primary,Backdrop,Thumb",
-            IncludeItemTypes: "Movie"
-        };
-
-        return ApiClient.getJSON(ApiClient.getUrl('Users/' + user.Id + '/Items/Latest', options)).then(function (items) {
-
-            var html = '';
-
-            var scrollX = enableScrollX();
-
-            if (items.length) {
-                html += '<h1 class="listHeader">' + Globalize.translate('HeaderLatestMovies') + '</h1>';
-                if (scrollX) {
-                    html += '<div is="emby-itemscontainer" class="hiddenScrollX itemsContainer">';
-                } else {
-                    html += '<div is="emby-itemscontainer" class="itemsContainer vertical-wrap">';
-                }
-                html += cardBuilder.getCardsHtml({
-                    items: items,
-                    shape: getPortraitShape(),
-                    showUnplayedIndicator: false,
-                    showChildCountIndicator: true,
-                    lazy: true,
-                    context: 'home',
-                    centerText: true,
-                    overlayPlayButton: true
-                });
-                html += '</div>';
-            }
-
-            elem.innerHTML = html;
-            ImageLoader.lazyChildren(elem);
-        });
-    }
-
-    function loadLatestEpisodes(elem, user) {
-
-        var options = {
-
-            Limit: 12,
-            Fields: "PrimaryImageAspectRatio,BasicSyncInfo",
-            ImageTypeLimit: 1,
-            EnableImageTypes: "Primary,Backdrop,Thumb",
-            IncludeItemTypes: "Episode"
-        };
-
-        return ApiClient.getJSON(ApiClient.getUrl('Users/' + user.Id + '/Items/Latest', options)).then(function (items) {
-
-            var html = '';
-
-            var scrollX = enableScrollX();
-
-            if (items.length) {
-                html += '<h1 class="listHeader">' + Globalize.translate('HeaderLatestEpisodes') + '</h1>';
-                if (scrollX) {
-                    html += '<div is="emby-itemscontainer" class="hiddenScrollX itemsContainer">';
-                } else {
-                    html += '<div is="emby-itemscontainer" class="itemsContainer vertical-wrap">';
+                if (user.Configuration.LatestItemsExcludes.indexOf(item.Id) !== -1) {
+                    continue;
                 }
 
-                html += cardBuilder.getCardsHtml({
-                    items: items,
-                    preferThumb: true,
-                    shape: getThumbShape(),
-                    showUnplayedIndicator: false,
-                    showChildCountIndicator: true,
-                    lazy: true,
-                    context: 'home',
-                    overlayPlayButton: true
-                });
-                html += '</div>';
-            }
+                if (excludeViewTypes.indexOf(item.CollectionType || []) !== -1) {
+                    continue;
+                }
 
-            elem.innerHTML = html;
-            ImageLoader.lazyChildren(elem);
+                // not implemented yet
+                if (excludeItemTypes.indexOf(item.Type) !== -1) {
+                    continue;
+                }
+
+                var frag = document.createElement('div');
+                frag.classList.add('homePageSection');
+                elem.appendChild(frag);
+
+                renderLatestSection(frag, user, item);
+            }
         });
     }
 
@@ -433,62 +388,51 @@
             }
 
             elem.innerHTML = html;
-            ImageLoader.lazyChildren(elem);
+            imageLoader.lazyChildren(elem);
         });
     }
 
-    function loadLibraryTiles(elem, user, shape, index, autoHideOnMobile, showTitles) {
+    function loadLibraryTiles(elem, user, shape) {
 
         return getUserViews(user.Id).then(function (items) {
 
             var html = '';
 
-            if (autoHideOnMobile) {
-                html += '<div class="hiddenSectionOnMobile">';
-            } else {
-                html += '<div>';
-            }
+            html += '<div>';
 
             if (items.length) {
 
-                var screenWidth = dom.getWindowSize().innerWidth;
-
                 html += '<div>';
                 html += '<h1 class="listHeader">' + Globalize.translate('HeaderMyMedia') + '</h1>';
-
                 html += '</div>';
 
-                var scrollX = enableScrollX() && browserInfo.safari && screenWidth > 800;
+                var scrollX = enableScrollX() && dom.getWindowSize().innerWidth >= 500;
 
                 if (scrollX) {
                     html += '<div is="emby-itemscontainer" class="hiddenScrollX itemsContainer">';
                 } else {
                     html += '<div is="emby-itemscontainer" class="itemsContainer vertical-wrap">';
                 }
+
                 html += cardBuilder.getCardsHtml({
                     items: items,
-                    shape: scrollX ? 'overflowBackdrop' : shape,
-                    showTitle: showTitles,
+                    shape: scrollX ? 'overflowSmallBackdrop' : shape,
+                    showTitle: true,
                     centerText: true,
+                    overlayText: false,
                     lazy: true,
-                    autoThumb: true,
-                    transition: false
+                    transition: false,
+                    allowBottomPadding: !enableScrollX()
                 });
                 html += '</div>';
             }
 
             html += '</div>';
 
-            if (autoHideOnMobile) {
-                html += '<div class="hiddenSectionOnNonMobile" style="margin-top:1em;">';
-                html += getLibraryButtonsHtml(items);
-                html += '</div>';
-            }
-
             return getAppInfo().then(function (infoHtml) {
 
                 elem.innerHTML = html + infoHtml;
-                ImageLoader.lazyChildren(elem);
+                imageLoader.lazyChildren(elem);
             });
         });
     }
@@ -497,13 +441,24 @@
 
         var screenWidth = dom.getWindowSize().innerWidth;
 
+        var limit;
+
+        if (enableScrollX()) {
+
+            limit = 12;
+
+        } else {
+
+            limit = screenWidth >= 1920 ? 8 : (screenWidth >= 1600 ? 8 : (screenWidth >= 1200 ? 9 : 6));
+            limit = Math.min(limit, 5);
+        }
+
         var options = {
 
             SortBy: "DatePlayed",
             SortOrder: "Descending",
-            MediaTypes: "Video",
             Filters: "IsResumable",
-            Limit: screenWidth >= 1920 ? 8 : (screenWidth >= 1600 ? 8 : (screenWidth >= 1200 ? 9 : 6)),
+            Limit: limit,
             Recursive: true,
             Fields: "PrimaryImageAspectRatio,BasicSyncInfo",
             CollapseBoxSetItems: false,
@@ -518,12 +473,16 @@
             var html = '';
 
             if (result.Items.length) {
-                html += '<h1 class="listHeader">' + Globalize.translate('HeaderResume') + '</h1>';
+                html += '<h1 class="listHeader">' + Globalize.translate('HeaderContinueWatching') + '</h1>';
                 if (enableScrollX()) {
                     html += '<div is="emby-itemscontainer" class="hiddenScrollX itemsContainer">';
                 } else {
                     html += '<div is="emby-itemscontainer" class="itemsContainer vertical-wrap">';
                 }
+
+                var supportsImageAnalysis = appHost.supports('imageanalysis');
+                var cardLayout = supportsImageAnalysis;
+
                 html += cardBuilder.getCardsHtml({
                     items: result.Items,
                     preferThumb: true,
@@ -535,14 +494,19 @@
                     showDetailsMenu: true,
                     overlayPlayButton: true,
                     context: 'home',
-                    centerText: true
+                    centerText: !cardLayout,
+                    allowBottomPadding: false,
+                    cardLayout: cardLayout,
+                    showYear: true,
+                    lines: 2,
+                    vibrant: cardLayout && supportsImageAnalysis
                 });
                 html += '</div>';
             }
 
             elem.innerHTML = html;
 
-            ImageLoader.lazyChildren(elem);
+            imageLoader.lazyChildren(elem);
         });
     }
 
@@ -550,7 +514,7 @@
 
         var query = {
 
-            Limit: 20,
+            Limit: enableScrollX() ? 20 : 10,
             Fields: "PrimaryImageAspectRatio,SeriesInfo,DateCreated,BasicSyncInfo",
             UserId: userId,
             ImageTypeLimit: 1,
@@ -568,6 +532,9 @@
                 } else {
                     html += '<div is="emby-itemscontainer" class="itemsContainer vertical-wrap">';
                 }
+
+                var supportsImageAnalysis = appHost.supports('imageanalysis');
+
                 html += cardBuilder.getCardsHtml({
                     items: result.Items,
                     preferThumb: true,
@@ -578,14 +545,17 @@
                     lazy: true,
                     overlayPlayButton: true,
                     context: 'home',
-                    centerText: true
+                    centerText: !supportsImageAnalysis,
+                    allowBottomPadding: !enableScrollX(),
+                    cardLayout: supportsImageAnalysis,
+                    vibrant: supportsImageAnalysis
                 });
                 html += '</div>';
             }
 
             elem.innerHTML = html;
 
-            ImageLoader.lazyChildren(elem);
+            imageLoader.lazyChildren(elem);
         });
     }
 
@@ -663,11 +633,11 @@
 
             var elem = page.querySelector('#channel' + channel.Id + '');
             elem.innerHTML = html;
-            ImageLoader.lazyChildren(elem);
+            imageLoader.lazyChildren(elem);
         });
     }
 
-    function loadLatestLiveTvRecordings(elem, userId, index) {
+    function loadLatestLiveTvRecordings(elem, userId) {
 
         return ApiClient.getLiveTvRecordings({
 
@@ -675,7 +645,8 @@
             limit: 5,
             Fields: "PrimaryImageAspectRatio,BasicSyncInfo",
             IsInProgress: false,
-            EnableTotalRecordCount: false
+            EnableTotalRecordCount: false,
+            IsLibraryItem: false
 
         }).then(function (result) {
 
@@ -683,10 +654,8 @@
 
             if (result.Items.length) {
 
-                var cssClass = index !== 0 ? 'listHeader' : 'listHeader';
-
                 html += '<div>';
-                html += '<h1 style="display:inline-block; vertical-align:middle;" class="' + cssClass + '">' + Globalize.translate('HeaderLatestTvRecordings') + '</h1>';
+                html += '<h1 style="display:inline-block; vertical-align:middle;" class="listHeader">' + Globalize.translate('HeaderLatestTvRecordings') + '</h1>';
                 html += '<a href="livetv.html?tab=3" onclick="LibraryBrowser.showTab(\'livetv.html\',3);" class="clearLink" style="margin-left:2em;"><button is="emby-button" type="button" class="raised more mini"><span>' + Globalize.translate('ButtonMore') + '</span></button></a>';
                 html += '</div>';
             }
@@ -696,6 +665,9 @@
             } else {
                 html += '<div is="emby-itemscontainer" class="itemsContainer vertical-wrap">';
             }
+
+            var supportsImageAnalysis = appHost.supports('imageanalysis');
+
             html += cardBuilder.getCardsHtml({
                 items: result.Items,
                 shape: enableScrollX() ? 'autooverflow' : 'auto',
@@ -704,13 +676,19 @@
                 coverImage: true,
                 lazy: true,
                 showDetailsMenu: true,
-                centerText: true,
-                overlayPlayButton: true
+                centerText: !supportsImageAnalysis,
+                overlayText: false,
+                overlayPlayButton: true,
+                allowBottomPadding: !enableScrollX(),
+                preferThumb: true,
+                cardLayout: supportsImageAnalysis,
+                vibrant: supportsImageAnalysis
+
             });
             html += '</div>';
 
             elem.innerHTML = html;
-            ImageLoader.lazyChildren(elem);
+            imageLoader.lazyChildren(elem);
         });
     }
 
@@ -722,9 +700,7 @@
         loadNextUp: loadNextUp,
         loadLatestChannelItems: loadLatestChannelItems,
         loadLatestLiveTvRecordings: loadLatestLiveTvRecordings,
-        loadlibraryButtons: loadlibraryButtons,
-        loadLatestMovies: loadLatestMovies,
-        loadLatestEpisodes: loadLatestEpisodes
+        loadlibraryButtons: loadlibraryButtons
     };
 
     return window.Sections;
