@@ -1,4 +1,5 @@
-﻿define(['datetime', 'scrollStyles'], function (datetime) {
+﻿define(['datetime', 'libraryBrowser', 'cardBuilder', 'apphost', 'imageLoader', 'scrollStyles', 'emby-itemscontainer'], function (datetime, libraryBrowser, cardBuilder, appHost, imageLoader) {
+    'use strict';
 
     function getUpcomingPromise(context, params) {
 
@@ -7,7 +8,7 @@
         var query = {
 
             Limit: 40,
-            Fields: "AirTime,UserData,SeriesStudio,SyncInfo",
+            Fields: "AirTime,UserData",
             UserId: Dashboard.getCurrentUserId(),
             ImageTypeLimit: 1,
             EnableImageTypes: "Primary,Backdrop,Banner,Thumb",
@@ -39,7 +40,7 @@
     }
 
     function enableScrollX() {
-        return browserInfo.mobile && AppInfo.enableAppLayouts;
+        return browserInfo.mobile;
     }
 
     function getThumbShape() {
@@ -66,10 +67,10 @@
 
                     var premiereDate = datetime.parseISO8601Date(item.PremiereDate, true);
 
-                    if (premiereDate.getDate() == new Date().getDate() - 1) {
+                    if (datetime.isRelativeDay(premiereDate, -1)) {
                         dateText = Globalize.translate('Yesterday');
                     } else {
-                        dateText = LibraryBrowser.getFutureDateText(premiereDate, true);
+                        dateText = libraryBrowser.getFutureDateText(premiereDate, true);
                     }
 
                 } catch (err) {
@@ -101,23 +102,31 @@
             html += '<div class="homePageSection">';
             html += '<h1 class="listHeader">' + group.name + '</h1>';
 
+            var allowBottomPadding = true;
+
             if (enableScrollX()) {
-                html += '<div class="itemsContainer hiddenScrollX">';
+                allowBottomPadding = false;
+                html += '<div is="emby-itemscontainer" class="itemsContainer hiddenScrollX">';
             } else {
-                html += '<div class="itemsContainer">';
+                html += '<div is="emby-itemscontainer" class="itemsContainer vertical-wrap">';
             }
 
-            html += LibraryBrowser.getPosterViewHtml({
+            var supportsImageAnalysis = appHost.supports('imageanalysis');
+
+            html += cardBuilder.getCardsHtml({
                 items: group.items,
                 showLocationTypeIndicator: false,
                 shape: getThumbShape(),
                 showTitle: true,
-                showPremiereDate: true,
                 preferThumb: true,
                 lazy: true,
                 showDetailsMenu: true,
-                centerText: true,
-                overlayMoreButton: true
+                centerText: !supportsImageAnalysis,
+                showParentTitle: true,
+                overlayText: false,
+                allowBottomPadding: allowBottomPadding,
+                cardLayout: supportsImageAnalysis,
+                vibrant: supportsImageAnalysis
 
             });
             html += '</div>';
@@ -126,8 +135,7 @@
         }
 
         elem.innerHTML = html;
-        LibraryBrowser.createCardMenus(elem);
-        ImageLoader.lazyChildren(elem);
+        imageLoader.lazyChildren(elem);
     }
 
     return function (view, params, tabContent) {
