@@ -1,4 +1,5 @@
-﻿define(['jQuery', 'paper-icon-button-light', 'cardStyle'], function ($) {
+﻿define(['jQuery', 'humanedate', 'paper-icon-button-light', 'cardStyle'], function ($) {
+    'use strict';
 
     function deleteUser(page, id) {
 
@@ -6,7 +7,14 @@
 
         require(['confirm'], function (confirm) {
 
-            confirm(msg, Globalize.translate('DeleteUser')).then(function () {
+            confirm({
+                
+                title: Globalize.translate('DeleteUser'),
+                text: msg,
+                confirmText: Globalize.translate('ButtonDelete'),
+                primary: 'cancel'
+
+            }).then(function () {
 
                 Dashboard.showLoadingMsg();
 
@@ -61,13 +69,13 @@
                     switch (id) {
 
                         case 'open':
-                            Dashboard.navigate('useredit.html?userid=' + userId);
+                            Dashboard.navigate('useredit.html?userId=' + userId);
                             break;
                         case 'access':
-                            Dashboard.navigate('userlibraryaccess.html?userid=' + userId);
+                            Dashboard.navigate('userlibraryaccess.html?userId=' + userId);
                             break;
                         case 'parentalcontrol':
-                            Dashboard.navigate('userparentalcontrol.html?userid=' + userId);
+                            Dashboard.navigate('userparentalcontrol.html?userId=' + userId);
                             break;
                         case 'delete':
                             deleteUser(page, userId);
@@ -85,7 +93,7 @@
 
         var html = '';
 
-        var cssClass = "card squareCard scalableCard";
+        var cssClass = "card squareCard scalableCard squareCard-scalable";
 
         if (user.Policy.IsDisabled) {
             cssClass += ' grayscale';
@@ -145,6 +153,16 @@
         html += user.Name;
         html += "</div>";
 
+        html += '<div class="cardText cardText-secondary">';
+        var lastSeen = getLastSeenText(user.LastActivityDate);
+        if (lastSeen != "") {
+            html += lastSeen;
+        }
+        else {
+            html += "&nbsp;";
+        }
+        html += '</div>';
+
         // cardFooter
         html += "</div>";
 
@@ -157,6 +175,15 @@
         return html;
     }
 
+    function getLastSeenText(lastActivityDate) {
+
+        if (!lastActivityDate) {
+            return "";
+        }
+
+        return "Last seen " + humane_date(lastActivityDate);
+    }
+
     function getUserSectionHtml(users, addConnectIndicator) {
 
         var html = '';
@@ -204,9 +231,9 @@
 
         require(['actionsheet'], function (actionsheet) {
 
-            var card = $(elem).parents('.card');
-            var page = $(elem).parents('.page');
-            var id = card.attr('data-id');
+            var card = $(elem).parents('.card')[0];
+            var page = $(elem).parents('.page')[0];
+            var id = card.getAttribute('data-id');
 
             actionsheet.show({
                 items: menuItems,
